@@ -20,7 +20,6 @@ fn setup(mut commands: Commands, asset_server: Res<AssetServer>, materials: ResM
     commands.spawn_bundle(OrthographicCameraBundle::new_2d());
     commands.spawn_bundle(UiCameraBundle::default());
 
-    let lines = gerg_ui::read_ui_file("screen1.ui");
-    let controls = gerg_ui::instantiate_controls(lines);
-    gerg_ui::spawn_controls(&mut commands, asset_server, materials, controls);
+    let controls = gerg_ui::instantiate_controls_from_file("screen1.ui");
+    let _entities = gerg_ui::spawn_controls(&mut commands, asset_server, materials, controls, Vec2::new(1920.0, 1080.0));
 }
\ No newline at end of file
